@@ -5,6 +5,8 @@ from django.apps import AppConfig as DjangoApponfig
 from django.core.management import color_style
 from edc_export.utils import get_export_folder
 
+from edc_pdutils.site_values_mappings import site_values_mappings
+
 style = color_style()
 
 
@@ -13,7 +15,10 @@ class AppConfig(DjangoApponfig):
     verbose_name = "Edc Pandas Utilities"
     include_in_administration_section = False
 
-    def ready(self):
+    def ready(
+        self,
+    ):
+        sys.stdout.write(f"Loading {self.verbose_name} ...\n")
         if not os.path.exists(get_export_folder()):
             sys.stdout.write(
                 style.ERROR(
@@ -21,3 +26,6 @@ class AppConfig(DjangoApponfig):
                     f"See {self.name}.\n"
                 )
             )
+
+        site_values_mappings.autodiscover()
+        sys.stdout.write(f" Done loading {self.verbose_name}.\n")
