@@ -2,4 +2,6 @@ from .datetime_to_date import datetime_to_date
 from .decrypt import DecryptError, decrypt
 from .identity256 import identity256, identity256_decrypt
 from .missing_subject_identifiers import missing_subject_identifiers
+from .model_from_table_name import get_model_from_table_name
+from .table_names import get_model_names, get_table_names
 from .undash import undash
